summaryrefslogtreecommitdiff
path: root/lib/smarty/sysplugins/smarty_internal_compile_ldelim.php
diff options
context:
space:
mode:
authoremkael <emkael@tlen.pl>2018-10-18 02:39:34 +0200
committeremkael <emkael@tlen.pl>2018-10-18 02:39:42 +0200
commitab5d8d4e07bb3c8230d0285ef8902ef1979fce51 (patch)
tree0b955e585cb2fdbc7207392a5f2c97d610b6a5bc /lib/smarty/sysplugins/smarty_internal_compile_ldelim.php
parentc055ce2ab60c6582bad3e5babcb1d00384fde78a (diff)
Updating Smarty
Diffstat (limited to 'lib/smarty/sysplugins/smarty_internal_compile_ldelim.php')
-rw-r--r--lib/smarty/sysplugins/smarty_internal_compile_ldelim.php30
1 files changed, 13 insertions, 17 deletions
diff --git a/lib/smarty/sysplugins/smarty_internal_compile_ldelim.php b/lib/smarty/sysplugins/smarty_internal_compile_ldelim.php
index 9906325..5493d4e 100644
--- a/lib/smarty/sysplugins/smarty_internal_compile_ldelim.php
+++ b/lib/smarty/sysplugins/smarty_internal_compile_ldelim.php
@@ -1,41 +1,37 @@
<?php
/**
* Smarty Internal Plugin Compile Ldelim
- *
* Compiles the {ldelim} tag
*
- * @package Smarty
+ * @package Smarty
* @subpackage Compiler
- * @author Uwe Tews
+ * @author Uwe Tews
*/
/**
* Smarty Internal Plugin Compile Ldelim Class
*
- * @package Smarty
+ * @package Smarty
* @subpackage Compiler
*/
-class Smarty_Internal_Compile_Ldelim extends Smarty_Internal_CompileBase {
-
+class Smarty_Internal_Compile_Ldelim extends Smarty_Internal_CompileBase
+{
/**
* Compiles code for the {ldelim} tag
- *
* This tag does output the left delimiter
* @param array $args array with attributes from parser
* @param object $compiler compiler object
* @return string compiled code
+ * @throws \SmartyCompilerException
*/
- public function compile($args, $compiler)
+ public function compile($args, Smarty_Internal_TemplateCompilerBase $compiler)
{
$_attr = $this->getAttributes($compiler, $args);
- if ($_attr['nocache'] === true) {
- $compiler->trigger_template_error('nocache option not allowed', $compiler->lex->taglineno);
+ if ($_attr[ 'nocache' ] === true) {
+ $compiler->trigger_template_error('nocache option not allowed', null, true);
}
- // this tag does not return compiled code
- $compiler->has_code = true;
return $compiler->smarty->left_delimiter;
}
-
}
-
-?>
@@ -1,41 +1,37 @@
* This tag does output the left delimiter
- * @param array $args array with attributes from parser
- * @param object $compiler compiler object
+ *
+ * @param array $args array with attributes from parser
+ * @param \Smarty_Internal_TemplateCompilerBase $compiler compiler object
+ *
* @return string compiled code